@@ -1,6 +1,7 @@
 from ._async.base import AsyncByteStream, AsyncHTTPTransport
 from ._async.connection_pool import AsyncConnectionPool
 from ._async.http_proxy import AsyncHTTPProxy
+from ._bytestreams import PlainByteStream, AsyncIteratorByteStream, IteratorByteStream
 from ._exceptions import (
     CloseError,
     ConnectError,
@@ -8,10 +9,13 @@ from ._exceptions import (
     NetworkError,
     PoolTimeout,
     ProtocolError,
+    RemoteProtocolError,
+    LocalProtocolError,
     ProxyError,
     ReadError,
     ReadTimeout,
     TimeoutException,
+    UnsupportedProtocol,
     WriteError,
     WriteTimeout,
 )
@@ -38,5 +42,11 @@ __all__ = [
     "ReadError",
     "WriteError",
     "CloseError",
+    "LocalProtocolError",
+    "RemoteProtocolError",
+    "UnsupportedProtocol",
+    "AsyncIteratorByteStream",
+    "IteratorByteStream",
+    "PlainByteStream",
 ]
-__version__ = "0.9.1"
+__version__ = "0.10.0"
