@@ -1,5 +1,5 @@
 from ssl import SSLContext
-from typing import Optional, Union
+from typing import Optional
 
 import trio
 
@@ -22,7 +22,7 @@ def none_as_inf(value: Optional[float]) -> float:
 
 
 class SocketStream(AsyncSocketStream):
-    def __init__(self, stream: Union[trio.SocketStream, trio.SSLStream]) -> None:
+    def __init__(self, stream: trio.abc.Stream) -> None:
         self.stream = stream
         self.read_lock = trio.Lock()
         self.write_lock = trio.Lock()
@@ -43,7 +43,9 @@ class SocketStream(AsyncSocketStream):
             trio.BrokenResourceError: ConnectError,
         }
         ssl_stream = trio.SSLStream(
-            self.stream, ssl_context=ssl_context, server_hostname=hostname
+            self.stream,
+            ssl_context=ssl_context,
+            server_hostname=hostname.decode("ascii"),
         )
 
         with map_exceptions(exc_map):
@@ -58,7 +60,10 @@ class SocketStream(AsyncSocketStream):
         async with self.read_lock:
             with map_exceptions(exc_map):
                 with trio.fail_after(read_timeout):
-                    return await self.stream.receive_some(max_bytes=n)
+                    data = await self.stream.receive_some(max_bytes=n)
+                    if data == b"":
+                        raise ReadError("Server disconnected while attempting read")
+                    return data
 
     async def write(self, data: bytes, timeout: TimeoutDict) -> None:
         if not data:
@@ -85,7 +90,7 @@ class SocketStream(AsyncSocketStream):
         stream = self.stream
 
         # Peek through any SSLStream wrappers to get the underlying SocketStream.
-        while hasattr(stream, "transport_stream"):
+        while isinstance(stream, trio.SSLStream):
             stream = stream.transport_stream
         assert isinstance(stream, trio.SocketStream)
 
@@ -138,8 +143,14 @@ class TrioBackend(AsyncBackend):
         port: int,
         ssl_context: Optional[SSLContext],
         timeout: TimeoutDict,
+        *,
+        local_address: Optional[str],
     ) -> AsyncSocketStream:
         connect_timeout = none_as_inf(timeout.get("connect"))
+        # Trio will support local_address from 0.16.1 onwards.
+        # We only include the keyword argument if a local_address
+        #  argument has been passed.
+        kwargs: dict = {} if local_address is None else {"local_address": local_address}
         exc_map = {
             trio.TooSlowError: ConnectTimeout,
             trio.BrokenResourceError: ConnectError,
@@ -147,11 +158,13 @@ class TrioBackend(AsyncBackend):
 
         with map_exceptions(exc_map):
             with trio.fail_after(connect_timeout):
-                stream: trio.SocketStream = await trio.open_tcp_stream(hostname, port)
+                stream: trio.abc.Stream = await trio.open_tcp_stream(
+                    hostname, port, **kwargs
+                )
 
                 if ssl_context is not None:
                     stream = trio.SSLStream(
-                        stream, ssl_context, server_hostname=hostname
+                        stream, ssl_context, server_hostname=hostname.decode("ascii")
                     )
                     await stream.do_handshake()
 
