@@ -1,14 +1,10 @@
 import enum
 from types import TracebackType
-from typing import Iterator, Callable, List, Tuple, Type
+from typing import Iterator, List, Tuple, Type
 
 from .._types import URL, Headers, TimeoutDict
 
 
-def empty() -> Iterator:
-    yield b""
-
-
 class NewConnectionRequired(Exception):
     pass
 
@@ -44,25 +40,17 @@ class SyncByteStream:
     the `\\__iter__` method, and optionally the `close` method.
     """
 
-    def __init__(
-        self, iterator: Iterator[bytes] = None, close_func: Callable = None,
-    ) -> None:
-        self.iterator = empty() if iterator is None else iterator
-        self.close_func = close_func
-
     def __iter__(self) -> Iterator[bytes]:
         """
         Yield bytes representing the request or response body.
         """
-        for chunk in self.iterator:
-            yield chunk
+        yield b""  # pragma: nocover
 
     def close(self) -> None:
         """
         Must be called by the client to indicate that the stream has been closed.
         """
-        if self.close_func is not None:
-            self.close_func()
+        pass  # pragma: nocover
 
 
 class SyncHTTPTransport:
@@ -87,13 +75,16 @@ class SyncHTTPTransport:
         **Parameters:**
 
         * **method** - `bytes` - The HTTP method, such as `b'GET'`.
-        * **url** - `Tuple[bytes, bytes, int, bytes]` - The URL as a 4-tuple of
+        * **url** - `Tuple[bytes, bytes, Optional[int], bytes]` - The URL as a 4-tuple of
         (scheme, host, port, path).
         * **headers** - `Optional[List[Tuple[bytes, bytes]]]` - Any HTTP headers
         to send with the request.
         * **stream** - `Optional[SyncByteStream]` - The body of the HTTP request.
         * **timeout** - `Optional[Dict[str, Optional[float]]]` - A dictionary of
-        timeout values for I/O operations.
+        timeout values for I/O operations. Supported keys are "pool" for acquiring a
+        connection from the connection pool, "read" for reading from the connection,
+        "write" for writing to the connection and "connect" for opening the connection.
+        Values are floating point seconds.
 
         ** Returns:**
 
